(get-password in search)(get-password host port db user)Obtains the database password from the user's .pgpass file for the given host, port, database and username. Returns nil if the password can't be obtained.
Obtains the database password from the user's .pgpass file for the given host, port, database and username. Returns nil if the password can't be obtained.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |