Clojure only.

kameleon.repl


db-specclj

(db-spec dbname hostname port user password)

Creates the database connection spec to use when accessing the database using Korma.

Creates the database connection spec to use when accessing the database
using Korma.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries