(normalize-string s)Normalizes a string for use in comparisons. Comparisons in which this function is used on both sides will be case-insensitive with leading and trailing whitespace removed and consecutive whitespace collapsed to a single space.
Normalizes a string for use in comparisons. Comparisons in which this function is used on both sides will be case-insensitive with leading and trailing whitespace removed and consecutive whitespace collapsed to a single space.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |