(db-spec dbname hostname port user password)Creates the database connection spec to use when accessing the database using Korma.
Creates the database connection spec to use when accessing the database using Korma.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |